package net.wanji.web.controller.scheme;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.dto.CrossIdDTO;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.web.dto.LaneIdDTO;
import net.wanji.web.dto.LightIdDTO;
import net.wanji.web.dto.SaveSchemeConfigDTO;
import net.wanji.web.service.scheme.impl.SchemeConfigServiceImpl;
import net.wanji.web.vo.scheme.LaneIdsVO;
import net.wanji.web.vo.scheme.LightIdVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;

/**
 * @author Kent HAN
 * @date 2023/1/5 10:23
 */
@Api(value = "CrossConfigController", description = "方案管理-方案配置")
@RequestMapping("/schemeConfig")
@RestController
public class SchemeConfigController {
    private final SchemeConfigServiceImpl schemeConfigService;

    public SchemeConfigController(SchemeConfigServiceImpl schemeConfigService) {
        this.schemeConfigService = schemeConfigService;
    }

    @AspectLog(description = "保存方案配置", operationType = BaseEnum.OperationTypeEnum.UPDATE)
    @ApiOperation(value = "保存方案配置", notes = "保存方案配置", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/saveSchemeConfig",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = JsonViewObject.class),
    })
    public JsonViewObject saveSchemeConfig(@RequestBody SaveSchemeConfigDTO saveSchemeConfigDTO) {
        schemeConfigService.saveSchemeConfig(saveSchemeConfigDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success();
    }

    @AspectLog(description = "根据车道获取灯组信息", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "根据车道获取灯组信息", notes = "根据车道获取灯组信息", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/getLightByLane",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = LightIdVO.class),
    })
    public JsonViewObject getLightByLane(@RequestBody LaneIdDTO laneIdDTO) {
        LightIdVO lightIdVO = schemeConfigService.getLightByLane(laneIdDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(lightIdVO);
    }

    @AspectLog(description = "根据灯组获取车道信息", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "根据灯组获取车道信息", notes = "根据灯组获取车道信息", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/getLanesByLight",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = LaneIdsVO.class),
    })
    public JsonViewObject getLanesByLight(@RequestBody LightIdDTO lightIdDTO) {
        LaneIdsVO laneIdsVO = schemeConfigService.getLanesByLight(lightIdDTO);
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();

        return jsonViewObject.success(laneIdsVO);
    }

    @AspectLog(description = "方案配置列表", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @ApiOperation(value = "方案配置列表", notes = "方案配置列表", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/listSchemeConfig",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SaveSchemeConfigDTO.class),
    })
    public JsonViewObject listSchemeConfig(@RequestBody CrossIdDTO crossIdDTO) {
        SaveSchemeConfigDTO saveSchemeConfigDTO = schemeConfigService.listSchemeConfig(crossIdDTO);
        return JsonViewObject.newInstance().success(saveSchemeConfigDTO);
    }
}
